==> bigmemoryExtras_1.8.0.tgz: bigmemoryExtras/doc/bigmemoryExtras.R <==
### R code from vignette source 'bigmemoryExtras.Rnw'

###################################################
### code chunk number 1: <options
###################################################
  options(width=90)


###################################################
### code chunk number 2: introcode
###################################################
library(bigmemoryExtras)
data.file = file.path(tempdir(),"bigmat","ds")
x = matrix(1:9,ncol=3,dimnames=list(letters[1:3],LETTERS[1:3]))
ds = BigMatrix(x,data.file)
ds[,1] = 3:1
ds[,1]


###################################################
### code chunk number 3: reattach
###################################################
ds$backingfile
saveRDS(ds,file=file.path(tempdir(),"foo.rds"))
new.ds = readRDS(file=file.path(tempdir(),"foo.rds"))
new.ds[1:2,2:3]


###################################################
### code chunk number 4: S4methods
###################################################
nrow(ds)
ds$nrow()
ncol(ds)
ds$ncol()
dim(ds)
ds$dim()
dimnames(ds)
ds$dimnames()
length(ds)
ds$length()


###################################################
### code chunk number 5: factorcode
###################################################
data.file = file.path(tempdir(),"bigmat","fs")
x = matrix( c(rep("AA",5),rep("BB",4)) ,ncol=3,dimnames=list(letters[1:3],LETTERS[1:3]))
fs = BigMatrixFactor(x,data.file,levels=c("AA","BB"))
fs[,]
as(fs,"matrix")
fs$levels
levels(fs)
fs[, 2]
fs[, 2:3]


###################################################
### code chunk number 6: eset
###################################################
library(Biobase)
eset = ExpressionSet()
assayDataElement(eset,"exprs") = ds
exprs(eset)[1:2,2:3]

new.dir = file.path(tempdir(),"newbigmat")
dir.create(new.dir,showWarnings=FALSE)
file.copy(ds$backingfile, new.dir)
updateAssayDataElementPaths( assayData(eset), new.dir )
assayDataElement(eset,"exprs")$backingfile
attachAssayDataElements( eset )

==> bigmemoryExtras_1.12.0.tgz: bigmemoryExtras/doc/bigmemoryExtras.R <==
### R code from vignette source 'bigmemoryExtras.Rnw'

###################################################
### code chunk number 1: <options
###################################################
  options(width=90)


###################################################
### code chunk number 2: introcode
###################################################
library(bigmemoryExtras)
data.file = file.path(tempdir(),"bigmat","ds")
x = matrix(1:9,ncol=3,dimnames=list(letters[1:3],LETTERS[1:3]))
ds = BigMatrix(x,data.file)
ds[,1] = 3:1
ds[,1]


###################################################
### code chunk number 3: reattach
###################################################
ds$backingfile
saveRDS(ds,file=file.path(tempdir(),"foo.rds"))
new.ds = readRDS(file=file.path(tempdir(),"foo.rds"))
new.ds[1:2,2:3]


###################################################
### code chunk number 4: S4methods
###################################################
nrow(ds)
ds$nrow()
ncol(ds)
ds$ncol()
dim(ds)
ds$dim()
dimnames(ds)
ds$dimnames()
length(ds)
ds$length()


###################################################
### code chunk number 5: factorcode
###################################################
data.file = file.path(tempdir(),"bigmat","fs")
x = matrix( c(rep("AA",5),rep("BB",4)) ,ncol=3,dimnames=list(letters[1:3],LETTERS[1:3]))
fs = BigMatrixFactor(x,data.file,levels=c("AA","BB"))
fs[,]
as(fs,"matrix")
fs$levels
levels(fs)
fs[, 2]
fs[, 2:3]


###################################################
### code chunk number 6: se
###################################################
library(GenomicRanges)
se = SummarizedExperiment(assays=list(a=ds, b=fs))
assays(se)[["a"]]
new.dir = file.path(tempdir(),"newbigmat")
dir.create(new.dir,showWarnings=FALSE)
file.copy(ds$backingfile, new.dir)
file.copy(fs$backingfile, new.dir)
assays(se) = updateBackingfiles(assays(se), new.dir)
assays(se)[["b"]]$backingfile


###################################################
### code chunk number 7: eset
###################################################
library(Biobase)
eset = ExpressionSet()
data.file = file.path(tempdir(),"bigmat","ds")
x = matrix(1:9,ncol=3,dimnames=list(letters[1:3],LETTERS[1:3]))
ds = BigMatrix(x,data.file)
assayDataElement(eset,"exprs") = ds
exprs(eset)[1:2,2:3]

new.dir = file.path(tempdir(),"newbigmat")
dir.create(new.dir,showWarnings=FALSE)
file.copy(ds$backingfile, new.dir)
assayData(eset) = updateBackingfiles(assayData(eset), new.dir)
assayDataElement(eset,"exprs")$backingfile
